/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.vehicle;

import java.util.ArrayList;
import java.util.List;
import nl.cloudfarming.client.fleet.model.Machine;
import nl.cloudfarming.client.fleet.model.VehicleManager;
import nl.cloudfarming.client.fleet.model.VehicleService;
import nl.cloudfarming.client.fleet.vehicle.tree.VehicleCategoryNodeFactory;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;
import org.openide.util.Lookup;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 * @author Wytse Visser
 */
@ServiceProvider(service = VehicleService.class)
public class VehicleServiceImpl implements VehicleService {

    @Override
    public List<Machine> getMachines(Project fleetProject) {
        List<Machine> vehicleList = new ArrayList<>();
        FileObject vehiclesDir = getVehiclesDirectory(fleetProject);
        if (vehiclesDir != null) {
            FileObject[] children = vehiclesDir.getChildren();
            for (FileObject child : children) {
                vehicleList.add(loadMachine(child));
            }
        }

        return vehicleList;
    }

    @Override
    public Machine getMachine(Project fleetProject, String name) {
        Machine machine = null;
        FileObject implementsDir = getVehiclesDirectory(fleetProject);
        if (implementsDir != null) {
            return loadMachine(implementsDir.getFileObject(name, "vce"));
        }

        return machine;
    }

    private static FileObject getVehiclesDirectory(Project fleetProject) {
        String ImplementsDirName = VehicleCategoryNodeFactory.getDirectoryName();
        return fleetProject.getProjectDirectory().getFileObject(ImplementsDirName);
    }

    private static Machine loadMachine(FileObject machineFile) {
        if (machineFile == null) {
            return null;
        }

        Lookup lookup = Lookup.getDefault();
        VehicleManager implementManager = lookup.lookup(VehicleManager.class);
        return implementManager.load(machineFile);
    }
}
