/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.vehicle.tree;

import java.util.List;
import javax.swing.Action;
import nl.cloudfarming.client.fleet.machine.tree.MachineCategoryChildFactory;
import nl.cloudfarming.client.fleet.machine.tree.MachineCategoryNode;
import nl.cloudfarming.client.fleet.model.Machine;
import nl.cloudfarming.client.fleet.model.MachineService;
import nl.cloudfarming.client.fleet.model.VehicleService;
import nl.cloudfarming.client.fleet.vehicle.wizard.VehicleWizardAction;
import org.netbeans.api.project.Project;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

/**
 *
 * @author Wytse Visser
 */
public final class VehicleCategoryNode extends MachineCategoryNode {

    private Project project;
    private static MachineMetaInfo metaInfo;

    public VehicleCategoryNode(Project project, MachineCategoryChildFactory childFactory) {
        super(childFactory);
        this.project = project;

        setDisplayName(getMetaInfo().getDisplayName());
        setIconBaseWithExtension(getMetaInfo().getSmallIconResource());
    }

    @Override
    public final MachineMetaInfo getMetaInfo() {
        if (metaInfo == null) {
            metaInfo = new VehicleCategoryInfo();
        }
        return metaInfo;
    }

    @Override
    public List<Machine> getMachines() {
        MachineService service = Lookup.getDefault().lookup(VehicleService.class);
        return service.getMachines(project);
    }

    @Override
    public Action[] getActions(boolean context) {
        return new Action[]{
                    new OpenAction(),
                    null,
                    new VehicleWizardAction(project)
                };
    }

    @NbBundle.Messages("displayName=Vehicles")
    public static class VehicleCategoryInfo implements MachineMetaInfo {

        private final String ICON_SMALL = "nl/cloudfarming/client/fleet/vehicle/vehicle.png";
        private final String ICON_LARGE = "nl/cloudfarming/client/fleet/vehicle/vehicle32.png";

        @Override
        public String getDisplayName() {
            return Bundle.displayName();
        }

        @Override
        public String getSmallIconResource() {
            return ICON_SMALL;
        }

        @Override
        public String getLargeIconResource() {
            return ICON_LARGE;
        }
    }
}
